@@ -1,15 +1,16 @@
 package Finance::Bank::ID::Base;
 BEGIN {
-  $Finance::Bank::ID::Base::VERSION = '0.09';
+  $Finance::Bank::ID::Base::VERSION = '0.10';
 }
 # ABSTRACT: Base class for Finance::Bank::ID::BCA etc
 
 
+use 5.010;
 use Any::Moose;
 use Data::Dumper;
 use DateTime;
 use Log::Any;
-use WWW::Mechanize;
+use Finance::BankUtils::ID::Mechanize;
 
 
 has mech        => (is => 'rw');
@@ -26,6 +27,10 @@ has site => (is => 'rw');
 
 has _req_counter => (is => 'rw', default => 0);
 
+has verify_https => (is => 'rw', default => 0);
+has https_ca_dir => (is => 'rw', default => '/etc/ssl/certs');
+has https_host   => (is => 'rw');
+
 
 sub _fmtdate {
     my ($self, $dt) = @_;
@@ -54,13 +59,24 @@ sub BUILD {
     $self->password($args->{pin})   if $args->{pin}   && !$self->password;
 }
 
+sub _set_default_mech {
+    my ($self) = @_;
+    $self->mech(
+        Finance::BankUtils::ID::Mechanize->new(
+            verify_https => $self->verify_https,
+            https_ca_dir => $self->https_ca_dir,
+            https_host   => $self->https_host,
+        )
+    );
+}
+
 # if check_sub is supplied, then after the request it will be passed the mech
 # object and should return an error string. request is assumed to be failed if
 # error string is not empty.
 
 sub _req {
     my ($self, $meth, $args, $check_sub) = @_;
-    $self->mech(new WWW::Mechanize) unless $self->mech;
+    $self->_set_default_mech unless $self->mech;
     my $mech = $self->mech;
     my $c = $self->_req_counter + 1;
     $self->_req_counter($c);
@@ -227,7 +243,7 @@ Finance::Bank::ID::Base - Base class for Finance::Bank::ID::BCA etc
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
@@ -282,7 +298,7 @@ Parse HTML/text into statement data.
 
 =head1 AUTHOR
 
-  Steven Haryanto <stevenharyanto@gmail.com>
+Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
